/*=======================================
		Tables lagged regressions
=======================================*/


** LEFT PANEL

use meta_reall , clear
gen cot = 1
collapse (mean) jc jd gross net excess c_n (count) cot if sep_hir==0, by(c_code year) 

label data "Collapse version of estimates, mean by country year."
save mini_meta, replace

use gdp, clear
merge 1:1 c_code year using gini_new	
drop _merge

merge 1:m c_code year using mini_meta	
drop _merge

* To complete the id variables
egen aux = min(c_n), by(c_code)
replace c_n = aux if c_n==.
drop if c_n ==.
xtset c_n year


foreach var in jc jd gross net excess{
replace `var' = . if year >2000
}

global cols "lag_n jc se pval jd se pval gross se pval net se pval excess se pval"
foreach lhs in gini prod{

matrix `lhs' = J(11,16,-99)
matrix colnames  `lhs'  = $cols
quiet{
local v = 0
foreach var in jc jd gross net excess{
local ++v
forvalues i = 1/11{
local j = `i' -1


reg f`j'.`lhs' `var' i.year i.c_n [aw=cot], level(90)
estimates store `var'_`lhs'_`j'
matrix b = r(table)

matrix `lhs'[`i',1] = `j'
matrix `lhs'[`i',`v'*3-1]   = b[1,1]
matrix `lhs'[`i',`v'*3] 	= b[2,1]
matrix `lhs'[`i',`v'*3+1] 	= b[4,1]


}
} 
}
}



matrix l prod, format(%9.2f)
matrix l gini, format(%9.2f)




** RIGHT PANEL


use flows_lits, clear

replace hire =. if year >2000
replace sep =. if year >2000

merge 1:1 c_code year using gdp 
drop _merge

merge 1:1 c_code year using gini_vshort 
drop _merge


drop if c_code=="TKM"| c_code =="YUG"
drop if c_code =="BiH"|c_code=="SRB"| c_code == "MNE"
egen aux = min(c_n), by(c_code)
replace c_n = aux if c_n==.


gen same_cy = 0
replace same_cy = 1 if c_code=="BGR" & year>1989 & year<1998
replace same_cy = 1 if c_code=="CZE" & year>1993 & year<1999
replace same_cy = 1 if c_code=="EST" & year>1989 & year<2000
replace same_cy = 1 if c_code=="HUN" & year>1989 & year<1994
replace same_cy = 1 if c_code=="POL" & (year==1990 | (year>1993 & year<2000))
replace same_cy = 1 if c_code=="ROM" & ((year>1989 & year<1994) | (year>1994 & year<1998))
replace same_cy = 1 if c_code=="RUS" & year>1989 & year<1999
replace same_cy = 1 if c_code=="SVN" & year>1990 & year<2000
replace same_cy = 1 if c_code=="UKR" & year>1991 & year<2000

egen same_c  =max(same_cy), by(c_code)

gen all =1


drop if c_n ==.
replace hire = . if year>2000
replace sep = . if year>2000

gen gross = hire +sep
gen net = abs(hire-sep)
gen excess = gross - net


xtset c_n year
global cols "lag_n jc se pval jd se pval gross se pval net se pval excess se pval"
foreach var in same_cy {
foreach lhs in prod gini {

quiet{
matrix `lhs'_lits = J(11,16,-99)
matrix colnames `lhs'_lits = $cols

local v = 0
foreach rhs in hire sep gross net excess{
local ++v
forvalues i = 1/11{
local j = `i' -1


qui reg f`j'.`lhs' `rhs' i.c_n if year>=1989 & `var'==1, level(90)
matrix b = r(table)

matrix `lhs'_lits[`i',1] = `j'
matrix `lhs'_lits[`i',`v'*3-1]   = b[1,1]
matrix `lhs'_lits[`i',`v'*3] 	= b[2,1]
matrix `lhs'_lits[`i',`v'*3+1] 	= b[4,1]


}
}
}

}
 
}
*

matrix l prod_lits, format(%9.2f)
matrix l gini_lits, format(%9.2f)

